"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LookupBuilderFactory = void 0;
const lookup_enum_1 = require("./lookup.enum");
const lookups_1 = require("./lookups");
const LOOKUP_FILTER_MAP = new Map([
    [lookup_enum_1.LookupFilter.EXACT, new lookups_1.ExactLookup()],
    [lookup_enum_1.LookupFilter.CONTAINS, new lookups_1.ContainsLookup()],
    [lookup_enum_1.LookupFilter.STARTS_WITH, new lookups_1.StartsWithLookup()],
    [lookup_enum_1.LookupFilter.ENDS_WITH, new lookups_1.EndsWithLookup()],
    [lookup_enum_1.LookupFilter.ICONTAINS, new lookups_1.InsensitiveContainsLookup()],
    [lookup_enum_1.LookupFilter.ISTARTS_WITH, new lookups_1.InsensitiveStartsWithLookup()],
    [lookup_enum_1.LookupFilter.IENDS_WITH, new lookups_1.InsensitiveEndsWithLookup()],
    [lookup_enum_1.LookupFilter.IS_NULL, new lookups_1.IsNullLookup()],
    [lookup_enum_1.LookupFilter.LT, new lookups_1.LowerThanLookup()],
    [lookup_enum_1.LookupFilter.LTE, new lookups_1.LowerThanOrEqualLookup()],
    [lookup_enum_1.LookupFilter.GT, new lookups_1.GreaterThanLookup()],
    [lookup_enum_1.LookupFilter.GTE, new lookups_1.GreaterThanOrEqualLookup()],
    [lookup_enum_1.LookupFilter.IN, new lookups_1.InLookup()],
    [lookup_enum_1.LookupFilter.BETWEEN, new lookups_1.BetweenLookup()],
]);
class LookupBuilderFactory {
    constructor() {
        this.lookups = LOOKUP_FILTER_MAP;
    }
    build(lookup) {
        const builder = this.lookups.get(lookup);
        if (!builder) {
            throw new Error(`Unsupported lookup ${lookup}`);
        }
        return builder;
    }
}
exports.LookupBuilderFactory = LookupBuilderFactory;
//# sourceMappingURL=lookup-builder-factory.js.map