"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FilterFactory = void 0;
const lookup_enum_1 = require("./field/lookup.enum");
const field_filter_1 = require("./field/field-filter");
class FilterFactory {
    get(query) {
        if (!this.isFieldFilter(query.key)) {
            throw new Error(`${query.key} is not a field`);
        }
        const prop = this.getProp(query);
        const hasNotOperator = this.hasNotOperator(query);
        const lookup = this.getLookupFilter(query, hasNotOperator);
        return new field_filter_1.FieldFilter({
            query: query.query,
            prop,
            lookup,
            value: query.value,
            notOperator: hasNotOperator,
        });
    }
    getLookupFilter(query, hasNotOperator) {
        const includesLookupDelimiter = query.key.includes(lookup_enum_1.LookupDelimiter.LOOKUP_DELIMITER);
        if (!includesLookupDelimiter) {
            return lookup_enum_1.LookupFilter.EXACT;
        }
        return query.key.split(lookup_enum_1.LookupDelimiter.LOOKUP_DELIMITER)[hasNotOperator ? 2 : 1];
    }
    getProp(query) {
        return query.key.split(lookup_enum_1.LookupDelimiter.LOOKUP_DELIMITER)[0];
    }
    hasNotOperator(query) {
        return query.key.includes(`${lookup_enum_1.LookupDelimiter.LOOKUP_DELIMITER}${lookup_enum_1.LookupFilter.NOT}`);
    }
    isFieldFilter(key) {
        if (!key.includes(lookup_enum_1.LookupDelimiter.RELATION_DELIMITER)) {
            return true;
        }
        return false;
    }
}
exports.FilterFactory = FilterFactory;
//# sourceMappingURL=filter-factory.js.map